import random
from typing import List, Optional
from sqlalchemy.orm import Session
from models.city import City
from schemas.city import CitySchema

def get_random_cities_in_nigeria(db: Session, limit: int = 10) -> List[CitySchema]:
    """
    Retrieves a list of random cities in Nigeria from the database.

    Args:
        db (Session): The database session.
        limit (int, optional): The maximum number of cities to retrieve. Defaults to 10.

    Returns:
        List[CitySchema]: A list of random city schemas.
    """
    cities = db.query(City).filter(City.country == "Nigeria").all()
    random_cities = random.sample(cities, min(limit, len(cities)))
    return [CitySchema.from_orm(city) for city in random_cities]

def get_city_by_id(db: Session, city_id: str) -> Optional[CitySchema]:
    """
    Retrieves a city by its ID from the database.

    Args:
        db (Session): The database session.
        city_id (str): The ID of the city to retrieve.

    Returns:
        Optional[CitySchema]: The city schema if found, otherwise None.
    """
    city = db.query(City).filter(City.id == city_id).first()
    return CitySchema.from_orm(city) if city else None